@@ -172,7 +172,6 @@ runAssembly <- function(config, constraints, xdata = NULL, objective = NULL) {
   }
 
   if (!isOptimal(MIP$status, solver)) {
-    #if (names(MIP$status) == "TM_TIME_LIMIT_EXCEEDED") browser()
     return(list(solver = solver, status = MIP$status, MIP = MIP, selected = NULL))
   }
 
@@ -184,16 +183,20 @@ runAssembly <- function(config, constraints, xdata = NULL, objective = NULL) {
 
   if (!is.null(constraints@stim_order)) {
     constraints@item_attrib@data$tmpsort <- 1:constraints@ni
-    constraints@item_attrib@data <- merge(constraints@item_attrib@data,
-                                     constraints@st_attrib@data[c("STINDEX", "STID", constraints@stim_order_by)],
-                                     by = "STID", all.x = TRUE, sort = FALSE)
+    constraints@item_attrib@data <- merge(
+      constraints@item_attrib@data,
+      constraints@st_attrib@data[c("STINDEX", "STID", constraints@stim_order_by)],
+      by = "STID", all.x = TRUE, sort = FALSE
+    )
     constraints@item_attrib@data <- constraints@item_attrib@data[order(constraints@item_attrib@data$tmpsort), ]
     constraints@item_attrib@data <- constraints@item_attrib@data[, !(colnames(constraints@item_attrib@data) %in% "tmpsort")]
   } else if (!is.null(constraints@st_attrib)) {
     constraints@item_attrib@data$tmpsort <- 1:constraints@ni
-    constraints@item_attrib@data <- merge(constraints@item_attrib@data,
-                                     constraints@st_attrib@data[c("STINDEX", "STID")],
-                                     by = "STID", all.x = TRUE, sort = FALSE)
+    constraints@item_attrib@data <- merge(
+      constraints@item_attrib@data,
+      constraints@st_attrib@data[c("STINDEX", "STID")],
+      by = "STID", all.x = TRUE, sort = FALSE
+    )
     constraints@item_attrib@data <- constraints@item_attrib@data[order(constraints@item_attrib@data$tmpsort), ]
     constraints@item_attrib@data <- constraints@item_attrib@data[, !(colnames(constraints@item_attrib@data) %in% "tmpsort")]
   }
@@ -212,32 +215,33 @@ runAssembly <- function(config, constraints, xdata = NULL, objective = NULL) {
     shadow_test    <- data.frame(cbind(shadow_test, info))
     if (constraints@set_based) {
       if (any(is.na(shadow_test[["STID"]]))) {
-        shadow_test          <- data.frame(cbind(.sequence = 1:nrow(shadow_test), shadow_test))
-        shadow_test_discrete <- shadow_test[is.na(shadow_test[["STID"]]), ]
-        shadow_test_discrete <- data.frame(cbind(shadow_test_discrete, meanInfo = shadow_test_discrete$info))
-        shadow_test_stimulus <- shadow_test[!is.na(shadow_test[["STID"]]), ]
-        mean_info <- tapply(shadow_test_stimulus$info, shadow_test_stimulus[["STID"]], mean)
-        mean_info <- data.frame(STID = names(mean_info), meanInfo = mean_info)
-        shadow_test_stimulus <- merge(shadow_test_stimulus, mean_info, by = "STID", all.x = TRUE, sort = FALSE)
-        shadow_test          <- rbind(shadow_test_discrete, shadow_test_stimulus)
-        shadow_test          <- shadow_test[order(shadow_test$.sequence), ]
-        shadow_test          <- shadow_test[-1]
+
+        # if is a mixed test
+
+        shadow_test_discrete <- shadow_test[is.na(shadow_test$STID), ]
+        shadow_test_discrete <- data.frame(cbind(shadow_test_discrete, set_info = shadow_test_discrete$info))
+
+        shadow_test_setbased <- shadow_test[!is.na(shadow_test$STID), ]
+        shadow_test_setbased <- appendMeanInfo(shadow_test_setbased, "STID", "set_info")
+
+        shadow_test <- rbind(shadow_test_discrete, shadow_test_setbased)
+
       } else {
-        mean_info   <- tapply(shadow_test$info, shadow_test[["STID"]], mean)
-        mean_info   <- data.frame(STID = names(mean_info), meanInfo = mean_info)
-        shadow_test <- merge(shadow_test, mean_info, by = "STID", all.x = TRUE, sort = FALSE)
+
+        shadow_test <- appendMeanInfo(shadow_test, "STID", "set_info")
+
       }
     }
   }
 
   if (sort_by_info) {
-    shadow_test <- shadow_test[order(shadow_test[["info"]], decreasing = TRUE), ]
+    shadow_test <- shadow_test[order(shadow_test$info, decreasing = TRUE), ]
   }
   if (constraints@set_based) {
-    shadow_test <- shadow_test[order(shadow_test[["STID"]]), ]
+    shadow_test <- shadow_test[order(shadow_test$STID), ]
   }
   if (constraints@set_based & sort_by_info) {
-    shadow_test <- shadow_test[order(shadow_test[["meanInfo"]], decreasing = TRUE), ]
+    shadow_test <- shadow_test[order(shadow_test$set_info, decreasing = TRUE), ]
   }
   if (!is.null(constraints@item_order_by)) {
     shadow_test <- shadow_test[order(shadow_test[[constraints@item_order_by]]), ]
