@@ -12,6 +12,12 @@ double h_2pl(
   const double&,
   const double&);
 
+arma::mat h_m_2pl(
+  const arma::rowvec&,
+  const arma::rowvec&,
+  const double&,
+  const double&);
+
 double h_3pl(
   const arma::rowvec&,
   const double&,
@@ -19,6 +25,13 @@ double h_3pl(
   const double&,
   const double&);
 
+arma::mat h_m_3pl(
+  const arma::rowvec&,
+  const arma::rowvec&,
+  const double&,
+  const double&,
+  const double&);
+
 double h_pc(
   const arma::rowvec&,
   const arma::rowvec&,
@@ -30,12 +43,24 @@ double h_gpc(
   const arma::rowvec&,
   const double&);
 
+arma::mat h_m_gpc(
+  const arma::rowvec&,
+  const arma::rowvec&,
+  const arma::rowvec&,
+  const double&);
+
 double h_gr(
   const arma::rowvec&,
   const double&,
   const arma::rowvec&,
   const double&);
 
+arma::mat h_m_gr(
+  const arma::rowvec&,
+  const arma::rowvec&,
+  const arma::rowvec&,
+  const double&);
+
 arma::colvec array_h_1pl(
   const arma::mat&,
   const double&,
